AppConfig class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apiTimeout → const Duration
- appName → const String
- appVersion → const String
- baseUrl → const String
- cacheExpiry → const Duration
- enableAnalytics → const bool
- enableCloudSync → const bool
- enableCrashReporting → const bool
- itemsPerPage → const int
- maxRetries → const int