AppItem class

Constructors

AppItem({required String id, required String title, required String description, String? imageUrl, String category = 'General', bool isFavorite = false, DateTime? createdAt, DateTime? updatedAt})
AppItem.fromJson(Map<String, dynamic> json)
factory

Properties

category String
getter/setter pair
createdAt DateTime
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
imageUrl String?
getter/setter pair
isFavorite bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair
updatedAt DateTime
getter/setter pair

Methods

copyWith({String? title, String? description, String? imageUrl, String? category, bool? isFavorite}) AppItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited