SnapMapSettings class

Constructors

SnapMapSettings({String themeName = 'Ocean', String layout = 'radial', double textSize = 14.0, double branchThickness = 2.5, bool isCompact = false})

Properties

branchThickness double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isCompact bool
getter/setter pair
layout String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textSize double
getter/setter pair
themeName String
getter/setter pair

Methods

copyWith({String? themeName, String? layout, double? textSize, double? branchThickness, bool? isCompact}) SnapMapSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited