ItemProvider class
- Inheritance
-
- Object
- ChangeNotifier
- ItemProvider
Constructors
Properties
-
categories
→ List<
String> -
no setter
-
favorites
→ List<
AppItem> -
no setter
-
filteredItems
→ List<
AppItem> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
items
→ List<
AppItem> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchQuery ↔ String
-
getter/setter pair
- selectedCategory ↔ String
-
getter/setter pair
Methods
-
addItem(
AppItem item) → void -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
deleteItem(
String id) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
getById(
String id) → AppItem? -
loadSampleData(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toggleFavorite(
String id) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateItem(
String id, AppItem updated) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited