AppRouter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateRoute(
RouteSettings routeSettings) → Route
Constants
- about → const String
- createItem → const String
- dashboard → const String
- editProfile → const String
- explore → const String
- favorites → const String
- forgotPassword → const String
- help → const String
- home → const String
- itemDetail → const String
- login → const String
- notifications → const String
- onboarding → const String
- profile → const String
- settings → const String
- shell → const String
- signup → const String
- terms → const String
- theme → const String