AuthService class

Constructors

AuthService()

Properties

currentUser AppUser?
no setter
hashCode int
The hash code for this object.
no setterinherited
isAuthenticated bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

login(String email, String password) Future<AppUser>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPassword(String email) Future<void>
restoreSession() Future<void>
signup(String name, String email, String password) Future<AppUser>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited