NotificationService class

Inheritance

Constructors

NotificationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
notifications List<AppNotification>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadCount int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addNotification(AppNotification notification) → void
clearAll() → void
dispose() → void
Discards any resources used by the object.
inherited
loadSampleNotifications() → void
markAllRead() → void
markAsRead(String id) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited