AppConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- hiveBoxName → const String
- itemsBoxName → const String
- keyCloudSync → const String
- keyDarkMode → const String
- keyHapticFeedback → const String
- keyNotifications → const String
- keyOnboardingSeen → const String
- keyProfileName → const String
- keyThemeName → const String
- keyUserId → const String
- keyWorkspaceName → const String
- userBoxName → const String